/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TreeViewComponent } from '../../treeview.component';
import { TreeItemLookup } from '../../treeitem-lookup.interface';
import { DropPosition } from './drop-position';
import { PreventableEvent } from './preventable-event';
import { TreeItemAddRemoveArgs } from './treeitem-add-remove-args';
/**
 * Arguments for the TreeView [`nodeDrop`]({% slug api_treeview_treeviewcomponent %}#toc-nodedrop) event.
 */
export declare class TreeItemDropEvent extends PreventableEvent implements TreeItemAddRemoveArgs {
    /**
     * A reference of the TreeView from which the dragged item originates.
     */
    sourceTree: TreeViewComponent;
    /**
     * A reference of the TreeView onto which the dragged item is dropped.
     */
    destinationTree: TreeViewComponent;
    /**
     * The look-up info for the dragged item.
     */
    sourceItem: TreeItemLookup;
    /**
     * The look-up info for the item onto which the dragged item is dropped.
     */
    destinationItem: TreeItemLookup;
    /**
     * Describes where the dragged item is dropped relative to the drop target item.
     */
    dropPosition: DropPosition;
    /**
     * The original pointer event holding details about the current pointer position.
     */
    originalEvent: PointerEvent;
    /**
     * @hidden
     */
    isValid: boolean;
    /**
     * @hidden
     */
    constructor(initializer: TreeItemAddRemoveArgs, originalEvent: PointerEvent);
    /**
     * Specifies if the drop action should be marked as valid.
     * If set to `false`, the [`addItem`]({% slug api_treeview_treeviewcomponent %}#toc-additem) and
     * [`removeItem`]({% slug api_treeview_treeviewcomponent %}#toc-removeitem) events will not be fired and the drag clue
     * will be animated back to the source item to indicate the action is marked as invalid.
     */
    setValid(isValid: boolean): void;
}
