/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, OnChanges, OnDestroy, OnInit, Renderer2, SimpleChanges } from '@angular/core';
import { NavigationService } from './navigation/navigation.service';
import { SelectionService } from './selection/selection.service';
import { ExpandStateService } from './expand-state.service';
import { IndexBuilderService } from './index-builder.service';
import { TreeViewLookupService } from './treeview-lookup.service';
import { TreeItem } from './treeitem.interface';
import { CheckedState } from './checkbox/checked-state';
import * as i0 from "@angular/core";
/**
 * @hidden
 *
 * A directive which manages the expanded state of the TreeView.
 */
export declare class TreeViewItemDirective implements OnInit, OnChanges, OnDestroy {
    private element;
    private expandService;
    private navigationService;
    private selectionService;
    private lookupService;
    private renderer;
    private ib;
    dataItem: any;
    index: string;
    parentDataItem: any;
    parentIndex: string;
    role: string;
    loadOnDemand: boolean;
    checkable: boolean;
    selectable: boolean;
    expandable: boolean;
    set isChecked(checked: CheckedState);
    isDisabled: boolean;
    isVisible: boolean;
    get isExpanded(): boolean;
    set isExpanded(isExpanded: boolean);
    get isSelected(): boolean;
    set isSelected(isSelected: boolean);
    get isButton(): boolean;
    get treeItem(): TreeItem;
    get parentTreeItem(): TreeItem;
    ariaChecked: string;
    readonly id: number;
    private _isExpanded;
    private _isSelected;
    private isInitialized;
    private subscriptions;
    constructor(element: ElementRef, expandService: ExpandStateService, navigationService: NavigationService, selectionService: SelectionService, lookupService: TreeViewLookupService, renderer: Renderer2, ib: IndexBuilderService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    subscribe(): void;
    private registerNavigationItem;
    private activateItem;
    private expand;
    private isFocusable;
    private focusItem;
    private moveLookupItem;
    private moveNavigationItem;
    private updateNodeAvailability;
    private setAriaAttributes;
    private updateTabIndex;
    private setAttribute;
    static ɵfac: i0.ɵɵFactoryDeclaration<TreeViewItemDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TreeViewItemDirective, "[kendoTreeViewItem]", never, { "dataItem": { "alias": "dataItem"; "required": false; }; "index": { "alias": "index"; "required": false; }; "parentDataItem": { "alias": "parentDataItem"; "required": false; }; "parentIndex": { "alias": "parentIndex"; "required": false; }; "role": { "alias": "role"; "required": false; }; "loadOnDemand": { "alias": "loadOnDemand"; "required": false; }; "checkable": { "alias": "checkable"; "required": false; }; "selectable": { "alias": "selectable"; "required": false; }; "expandable": { "alias": "expandable"; "required": false; }; "isChecked": { "alias": "isChecked"; "required": false; }; "isDisabled": { "alias": "isDisabled"; "required": false; }; "isVisible": { "alias": "isVisible"; "required": false; }; "isExpanded": { "alias": "isExpanded"; "required": false; }; "isSelected": { "alias": "isSelected"; "required": false; }; }, {}, never, never, true, never>;
}
